CCRestApi class

Constructors

CCRestApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

loggingOptions CCRestLogging
getter/setter pair
options CCRestOptions
getter/setter pair

Static Methods

getModule<T>() → T
init({required CCRestOptions restOptions, CCRestLogging? loggingOptions, required List modules}) → void
register(dynamic instance) → void